@@ -1,10 +1,10 @@
 /* LIBGIMP - The GIMP Library
  * Copyright (C) 1995-1997 Peter Mattis and Spencer Kimball
  *
- * This library is free software; you can redistribute it and/or
+ * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 3 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,9 +12,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library.  If not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GIMP_UI_H__
@@ -24,6 +23,8 @@
 
 #include <libgimpwidgets/gimpwidgets.h>
 
+#define __GIMP_UI_H_INSIDE__
+
 #include <libgimp/gimpuitypes.h>
 
 #include <libgimp/gimpexport.h>
@@ -35,7 +36,6 @@
 #include <libgimp/gimpgradientmenu.h>
 #include <libgimp/gimppalettemenu.h>
 #include <libgimp/gimppatternmenu.h>
-#include <libgimp/gimppixbuf.h>
 #include <libgimp/gimpprocbrowserdialog.h>
 #include <libgimp/gimpprocview.h>
 #include <libgimp/gimpprogressbar.h>
@@ -49,6 +49,8 @@
 #include <libgimp/gimppatternselectbutton.h>
 #include <libgimp/gimpzoompreview.h>
 
+#undef __GIMP_UI_H_INSIDE__
+
 G_BEGIN_DECLS
 
 /* For information look into the C source or the html documentation */
